<?php
/**
 * Template Controller
 * @copyright   Copyright (C) 2011 MicroEngine Inc.
 */
class Template_Controller extends Me_Controller
{
    /**
     * Controller名
     */
    protected $controller = 'Template';
    /**
     * Logicオブジェクト
     * @var Template_Logic
     */
    protected $logic;

    /**
     * テンプレート編集
     */
    public function edit()
    {
        License_Util::check_valid();
        User_Role::require_designer();
        $page_id = Me_Util::get_query_string('pi');

        $form = $this->logic->get_edit_template_form($page_id);

        // テンプレートのアクセス権確認
        $user_logic = new User_Logic();
        if (!$user_logic->check_access_priv($form->template_path)) {
            throw new Me_Exception(610);
        }

        // sessionに保存
        $_form_id = Me_Util::generate_form_id();
        Me_Util::set_form($form, $_form_id);
        
        // browser.iniの取得
        $browser_ini_path = APP_ROOT . '/def/config/browser.ini';
        if (file_exists(DATA_ROOT . '/config/browser.ini')) {
            $browser_ini_path = DATA_ROOT . '/config/browser.ini';
        }
        $cond_list = array_keys(parse_ini_file($browser_ini_path, true));

        $is_edit = (!empty($form->_id)) ? true : false;
        $page_title = $this->logic->get_page_title($is_edit);
        $this->set_data(compact('form', 'cond_list', 'is_edit', 'page_title', '_form_id'));
    }

    /**
     * テンプレート登録
     */
    public function post()
    {
        License_Util::check_valid();
        User_Role::require_designer();
        // sessionからFormを取得
        $form = Me_Util::get_form();
        $mapping = array(
            'template_type' => 'template_type',
            'main_template' => 'main_template',
            'cond' => 'cond',
            'output_method' => 'output_method',
            'char_code' => 'char_code',
            'note' => 'note',
            'source_code' => 'source_code',
            'init' => 'init',
        );
        Me_Util::post_data_to_object($form, $mapping);
        // テンプレートのアクセス権確認
        $user_logic = new User_Logic();
        if (!$user_logic->check_access_priv($form->template_path)) {
            throw new Me_Exception(610);
        }

        $is_edit = (!empty($form->_id)) ? true : false;

        if ($this->logic->register_template($form)) {
            // 登録成功
            if ($form->init === 'on') {
                // MEタグ内側のデータを初期値としてページを編集する。
                $this->redirect_path = '../Page/edit?init=on&pi=' . $form->page_id;
            } else {
                // トップページにリダイレクト
                $this->redirect_path = '../Main/index?path=' . $form->page_path;
                if ($is_edit) {
                    $this->flash = 'テンプレート（ ' . $form->template_path . ' ）を更新しました。';
                    Me_Logger::log(1610, array($form->template_path));
                } else {
                    $this->flash = 'テンプレート（ ' . $form->template_path . ' ）を作成しました。';
                    Me_Logger::log(1611, array($form->template_path));
                }
            }
            Me_Util::unset_form();
        } else {
            // 登録失敗
            $this->view = '/Template/edit.php';
            $page_title = $this->logic->get_page_title($is_edit);
            $_form_id = Me_Util::get_form_id();
            // ソースコードの実態参照がtextareaでデコードされないように、'&'を変換して２重エンコード状態にする
            $form->source_code = str_replace('&', '&amp;', $form->source_code);
            $this->set_data(compact('form', 'page_title', 'is_edit', '_form_id'));
        }
    }

    /**
     * プレビュー（インスペクタ）表示
     */
    public function preview()
    {
        User_Role::require_designer();
        // sessionからFormを取得
        $form = Me_Util::get_form();
        $form->source_code = Me_Util::get_post_data('source_code', '');
        $this->logic->preview($form);

        h::no_escape($form->source_code);
        $this->view = null;
    }

    /**
     * テンプレート削除処理
     */
    public function post_delete()
    {
        License_Util::check_valid();
        User_Role::require_designer();
        $result = 'false';
        $message = 'error';

        $template_id = Me_Util::get_post_data('template_id');
        if (empty($template_id)) {
            throw new Me_Exception(600);
        }

        // テンプレート情報取得
        $template = $this->logic->select($template_id);
        // テンプレートのアクセス権確認
        $user_logic = new User_Logic();
        if (!$user_logic->check_access_priv($template->template_path)) {
            throw new Me_Exception(610);
        }

        if ($this->logic->delete_template($template_id)) {
            $result = 'true';
            Me_Logger::log(1612, array($template->template_path));
        }

        $this->set_data(compact('result', 'message'));
    }
}